Module convert

Module convert 

Conversion graph traversal using BFS.

This module finds all possible conversions from a value by traversing a graph where nodes are values and edges are format conversions.

Functions

find_all_conversions
Find all possible conversions from a value using BFS.